
# Slot: entity positively regulates entity




URI: [biolink:entity_positively_regulates_entity](https://w3id.org/biolink/vocab/entity_positively_regulates_entity)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [entity regulates entity](entity_regulates_entity.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | activity directly positively regulates activity of |
| **Local names:** | | positively regulates (translator) |
|  | | activity directly positively regulates activity of (ro) |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0002450 |
| **Narrow Mappings:** | | SEMMEDDB:STIMULATES |
|  | | SEMMEDDB:stimulates |
|  | | hetio:UPREGULATES_AuG |
|  | | hetio:UPREGULATES_DuG |
| **Broad Mappings:** | | RO:0004034 |

